Enum Colored
pub enum Colored {
ForegroundColor(Color),
BackgroundColor(Color),
UnderlineColor(Color),
}Available on crate feature
term only.Expand description
Variants
ForegroundColor(Color)
A foreground color.
BackgroundColor(Color)
A background color.
UnderlineColor(Color)
An underline color. Important: doesn’t work on windows 10 or lower.
Implementations
impl Colored
impl Colored
pub fn parse_ansi(ansi: &str) -> Option<Colored>
pub fn parse_ansi(ansi: &str) -> Option<Colored>
Parse an ANSI foreground or background color.
This is the string that would appear within an ESC [ <str> m escape sequence, as found in
various configuration files.
Examples
use crossterm::style::{Colored::{self, ForegroundColor, BackgroundColor}, Color};
assert_eq!(Colored::parse_ansi("38;5;0"), Some(ForegroundColor(Color::Black)));
assert_eq!(Colored::parse_ansi("38;5;26"), Some(ForegroundColor(Color::AnsiValue(26))));
assert_eq!(Colored::parse_ansi("48;2;50;60;70"), Some(BackgroundColor(Color::Rgb { r: 50, g: 60, b: 70 })));
assert_eq!(Colored::parse_ansi("49"), Some(BackgroundColor(Color::Reset)));
assert_eq!(Colored::parse_ansi("invalid color"), None);Currently, 3/4 bit color values aren’t supported so return None.
See also: Color::parse_ansi.
pub fn ansi_color_disabled() -> bool
pub fn ansi_color_disabled() -> bool
Checks whether ansi color sequences are disabled by setting of NO_COLOR in environment as per https://no-color.org/
pub fn ansi_color_disabled_memoized() -> bool
pub fn set_ansi_color_disabled(val: bool)