Struct Attributes
pub struct Attributes(/* private fields */);Available on crate feature
term only.Expand description
a bitset for all possible attributes
Implementations
impl Attributes
impl Attributes
pub const fn none() -> Attributes
pub const fn none() -> Attributes
Returns the empty bitset.
pub const fn with(self, attribute: Attribute) -> Attributes
pub const fn with(self, attribute: Attribute) -> Attributes
Returns a copy of the bitset with the given attribute set. If it’s already set, this returns the bitset unmodified.
pub const fn without(self, attribute: Attribute) -> Attributes
pub const fn without(self, attribute: Attribute) -> Attributes
Returns a copy of the bitset with the given attribute unset. If it’s not set, this returns the bitset unmodified.
pub fn set(&mut self, attribute: Attribute)
pub fn set(&mut self, attribute: Attribute)
Sets the attribute. If it’s already set, this does nothing.
pub fn unset(&mut self, attribute: Attribute)
pub fn unset(&mut self, attribute: Attribute)
Unsets the attribute. If it’s not set, this changes nothing.
pub fn toggle(&mut self, attribute: Attribute)
pub fn toggle(&mut self, attribute: Attribute)
Sets the attribute if it’s unset, unset it if it is set.
pub fn extend(&mut self, attributes: Attributes)
pub fn extend(&mut self, attributes: Attributes)
Sets all the passed attributes. Removes none.